# ---------------------------------------------------------------------
# Copyright (c) 1996 Christian Krone. All rights reserved.
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Tcl itself.
# See also licence.terms
# ----------------------------------------------------------------------------

# ---------------------------------------------------------------------
# First and all we need the AdabasTcl extension.
# ---------------------------------------------------------------------

proc loadAdabastcl {} {
    global env auto_path

    if {![info exists env(DBROOT)]} {
	append err "This application is only functional, if the environment "
	append err "variable DBROOT is set correctly."

	tk_dialog .err "Fatal error" $err questhead 0 Exit  
        exit 1
    }

    lappend auto_path $env(DBROOT)/lib $env(DBROOT)/tcl

    if {[catch {package require Adabastcl} msg]} {
	append err "This application is only functional with the Adabastcl "
	append err "extension. While starting it, the following error occurs:"
	append err "\n\n$msg\n\n"
	append err "You must have set DBROOT correctly and you have to install "
	append err "the AdabasTcl extension to the Adabas D database server."

	tk_dialog .err "Fatal error" $err questhead 0 Exit  
        exit 2
    }

    # Just to be sure, that the extension is loaded. "package require" does
    # not actually load the shared library, but adds the commands only to the
    # list of the unknown procedures; this applies not to variables - and we
    # will need adabastcl_library more or less immediately.

    adabas version
}

# ----------------------------------------------------------------------
# Is Tk loaded at all? This error can happen, if e.g. the DISPLAY
# variable isn't set or points to the wrong display. Since the X server
# already complained to stdout, our messages here can be rather terse.
# ----------------------------------------------------------------------

if [catch {package require Tk}] {
    puts "GUI not available. Exited"
    exit 3
}

# ----------------------------------------------------------------------
# Now we have to do some limbo to get TclTk's version clear.
# 1. The argument of the -weight option of the grid command changed
#    from float into an integer.
# 2. Are we running as plugin or have a Tk version, that is capable of
#    reading gif out of the -data option?
# 3. Do we have a Tk with the new font command?
# 4. Do we have a Tk with the new menu bar mechanism?
# 5. Do we have a Tk, where buttons understand the -default option?
# 6. Do we have a Tk with native dialogs (tk_messageBox/tk_getOpenFile)?
# ----------------------------------------------------------------------

set tkCompat(gridWeightMax) [expr $tk_version >= 4.2 ? 100 : 1.0]
set tkCompat(gridWeightMin) [expr $tk_version >= 4.2 ?   0 : 0.0]
set tkCompat(imageViaData)  [expr $tk_version >= 4.4 || [info exists embed_args]]
set tkCompat(fontCmd)       [expr $tk_version >= 8.0]
set tkCompat(menubars)      [expr $tk_version >= 8.0]
set tkCompat(defaultButton) [expr $tk_version >= 8.0]
set tkCompat(nativeDialogs) [expr $tk_version >= 4.2]

# ----------------------------------------------------------------------
# If this is not a development environment, we redefine tkerror here, so
# that the user doesn't see the "See trace" and "Skip messages" buttons.
# ----------------------------------------------------------------------

if ![info exists env(ADABASTCL_APPLICATIONS_DEVELOPMENT)] {
    proc bgerror err {
	tk_messageBox -icon error -title "Error" -message "Error: $err"
    }
}
